@@ -1,13 +1,16 @@
+from __future__ import annotations
+
 import copy
 import importlib
 import importlib.util
 import os
+import platform
 import re
 import shutil
 import sys
 import types
 from pathlib import Path
-from typing import Any, Dict, Optional, Tuple, Union
+from typing import Any, Optional
 
 import click
 import uvicorn
@@ -15,7 +18,7 @@ import uvicorn.config
 
 import shiny
 
-from . import _autoreload, _hostenv, _static
+from . import _autoreload, _hostenv, _static, _utils
 
 
 @click.group()  # pyright: ignore[reportUnknownMemberType]
@@ -54,19 +57,16 @@ any of the following will work:
     "--port",
     type=int,
     default=8000,
-    help="Bind socket to this port.",
+    help="Bind socket to this port. If 0, a random port will be used.",
     show_default=True,
 )
 @click.option(
     "--autoreload-port",
-    type=str,
-    default="+123",
-    help="Bind autoreload socket to this port number. If the value begins with + or -, it will be added to the value of --port. Ignored if --reload is not used.",
+    type=int,
+    default=0,
+    help="Bind autoreload socket to this port. If 0, a random port will be used. Ignored if --reload is not used.",
     show_default=True,
 )
-@click.option(
-    "--debug", is_flag=True, default=False, help="Enable debug mode.", hidden=True
-)
 @click.option("--reload", is_flag=True, default=False, help="Enable auto-reload.")
 @click.option(
     "--ws-max-size",
@@ -97,43 +97,50 @@ any of the following will work:
     help="Treat APP as an application factory, i.e. a () -> <ASGI app> callable.",
     show_default=True,
 )
+@click.option(
+    "--launch-browser",
+    is_flag=True,
+    default=False,
+    help="Launch app browser after app starts, using the Python webbrowser module.",
+    show_default=True,
+)
 def run(
-    app: Union[str, shiny.App],
+    app: str | shiny.App,
     host: str,
     port: int,
-    autoreload_port: str,
-    debug: bool,
+    autoreload_port: int,
     reload: bool,
     ws_max_size: int,
     log_level: str,
     app_dir: str,
     factory: bool,
+    launch_browser: bool,
 ) -> None:
     return run_app(
         app,
         host=host,
         port=port,
         autoreload_port=autoreload_port,
-        debug=debug,
         reload=reload,
         ws_max_size=ws_max_size,
         log_level=log_level,
         app_dir=app_dir,
         factory=factory,
+        launch_browser=launch_browser,
     )
 
 
 def run_app(
-    app: Union[str, shiny.App] = "app:app",
+    app: str | shiny.App = "app:app",
     host: str = "127.0.0.1",
     port: int = 8000,
-    autoreload_port: str = "",
-    debug: bool = False,
+    autoreload_port: int = 0,
     reload: bool = False,
     ws_max_size: int = 16777216,
     log_level: Optional[str] = None,
     app_dir: Optional[str] = ".",
     factory: bool = False,
+    launch_browser: bool = False,
 ) -> None:
     """
     Starts a Shiny app. Press ``Ctrl+C`` (or ``Ctrl+Break`` on Windows) to stop.
@@ -152,9 +159,10 @@ def run_app(
     host
         The address that the app should listen on.
     port
-        The port that the app should listen on.
-    debug
-        Enable debug mode.
+        The port that the app should listen on. Set to 0 to use a random port.
+    autoreload_port
+        The port that should be used for an additional websocket that is used to support
+        hot-reload. Set to 0 to use a random port.
     reload
         Enable auto-reload.
     ws_max_size
@@ -163,6 +171,10 @@ def run_app(
         Log level.
     app_dir
         Look for ``app`` under this directory (by adding this to the ``PYTHONPATH``).
+    factory
+        Treat ``app`` as an application factory, i.e. a () -> <ASGI app> callable.
+    launch_browser
+        Launch app browser after app starts, using the Python webbrowser module.
 
     Tip
     ---
@@ -189,46 +201,47 @@ def run_app(
         run_app("myapp:my_app", app_dir="..")
     """
 
+    # If port is 0, randomize
+    if port == 0:
+        port = _utils.random_port(host=host)
+
+    os.environ["SHINY_HOST"] = host
+    os.environ["SHINY_PORT"] = str(port)
+
     if isinstance(app, str):
         app, app_dir = resolve_app(app, app_dir)
 
     if app_dir:
         app_dir = os.path.realpath(app_dir)
 
-    log_config: Dict[str, Any] = copy.deepcopy(uvicorn.config.LOGGING_CONFIG)
+    log_config: dict[str, Any] = copy.deepcopy(uvicorn.config.LOGGING_CONFIG)
 
     if reload and app_dir is not None:
         reload_dirs = [app_dir]
     else:
         reload_dirs = []
 
-    if reload and autoreload_port != "":
-        m = re.search("^([+-]?)(\\d+)$", autoreload_port)
-        if not m:
-            sys.stderr.write(
-                "Error: Couldn't understand the provided value for --autoreload-port\n"
-            )
-            exit(1)
-        autoreload_port_num = int(m.group(2))
-        if m.group(1) == "+":
-            autoreload_port_num += port
-        elif m.group(1) == "-":
-            autoreload_port_num = port - autoreload_port_num
+    if reload:
+        if autoreload_port == 0:
+            autoreload_port = _utils.random_port(host=host)
 
-        if autoreload_port_num == port:
+        if autoreload_port == port:
             sys.stderr.write(
                 "Autoreload port is already being used by the app; disabling autoreload\n"
             )
+            reload = False
         else:
-            setup_hot_reload(log_config, autoreload_port_num, port)
+            setup_hot_reload(log_config, autoreload_port, port, launch_browser)
+
+    if launch_browser and not reload:
+        setup_launch_browser(log_config)
 
     maybe_setup_rsw_proxying(log_config)
 
     uvicorn.run(  # pyright: ignore[reportUnknownMemberType]
-        app,
+        app,  # pyright: ignore[reportGeneralTypeIssues]
         host=host,
         port=port,
-        debug=debug,
         reload=reload,
         reload_dirs=reload_dirs,
         ws_max_size=ws_max_size,
@@ -240,7 +253,10 @@ def run_app(
 
 
 def setup_hot_reload(
-    log_config: Dict[str, Any], autoreload_port: int, app_port: int
+    log_config: dict[str, Any],
+    autoreload_port: int,
+    app_port: int,
+    launch_browser: bool,
 ) -> None:
     # The only way I've found to get notified when uvicorn decides to reload, is by
     # inserting a custom log handler.
@@ -248,12 +264,24 @@ def setup_hot_reload(
         "class": "shiny._autoreload.HotReloadHandler",
         "level": "INFO",
     }
-    log_config["loggers"]["uvicorn.error"]["handlers"] = ["shiny_hot_reload"]
+    if "handlers" not in log_config["loggers"]["uvicorn.error"]:
+        log_config["loggers"]["uvicorn.error"]["handlers"] = []
+    log_config["loggers"]["uvicorn.error"]["handlers"].append("shiny_hot_reload")
 
-    _autoreload.start_server(autoreload_port, app_port)
+    _autoreload.start_server(autoreload_port, app_port, launch_browser)
 
 
-def maybe_setup_rsw_proxying(log_config: Dict[str, Any]) -> None:
+def setup_launch_browser(log_config: dict[str, Any]):
+    log_config["handlers"]["shiny_launch_browser"] = {
+        "class": "shiny._launchbrowser.LaunchBrowserHandler",
+        "level": "INFO",
+    }
+    if "handlers" not in log_config["loggers"]["uvicorn.error"]:
+        log_config["loggers"]["uvicorn.error"]["handlers"] = []
+    log_config["loggers"]["uvicorn.error"]["handlers"].append("shiny_launch_browser")
+
+
+def maybe_setup_rsw_proxying(log_config: dict[str, Any]) -> None:
     # Replace localhost URLs emitted to the log, with proxied URLs
     if _hostenv.is_workbench():
         if "filters" not in log_config:
@@ -268,7 +296,7 @@ def is_file(app: str) -> bool:
     return "/" in app or app.endswith(".py")
 
 
-def resolve_app(app: str, app_dir: Optional[str]) -> Tuple[str, Optional[str]]:
+def resolve_app(app: str, app_dir: Optional[str]) -> tuple[str, Optional[str]]:
     # The `app` parameter can be:
     #
     # - A module:attribute name
@@ -277,7 +305,13 @@ def resolve_app(app: str, app_dir: Optional[str]) -> Tuple[str, Optional[str]]:
     #   - directory (look for app:app inside of it)
     # - A module name (look for :app) inside of it
 
-    module, _, attr = app.partition(":")
+    if platform.system() == "Windows" and re.match("^[a-zA-Z]:[/\\\\]", app):
+        # On Windows, need special handling of ':' in some cases, like these:
+        #   shiny run c:/Users/username/Documents/myapp/app.py
+        #   shiny run c:\Users\username\Documents\myapp\app.py
+        module, attr = app, ""
+    else:
+        module, _, attr = app.partition(":")
     if not module:
         raise ImportError("The APP parameter cannot start with ':'.")
     if not attr:
