@@ -1,11 +1,15 @@
+# Needed for types imported only during TYPE_CHECKING with Python 3.7 - 3.9
+# See https://www.python.org/dev/peps/pep-0655/#usage-in-python-3-11
+from __future__ import annotations
+
+import re
 from contextlib import contextmanager
 from contextvars import ContextVar, Token
-import re
 from typing import Pattern, Union
 
 
 class ResolvedId(str):
-    def __call__(self, id: "Id") -> "ResolvedId":
+    def __call__(self, id: Id) -> ResolvedId:
         if isinstance(id, ResolvedId):
             return id
 
@@ -23,7 +27,22 @@ Root: ResolvedId = ResolvedId("")
 Id = Union[str, ResolvedId]
 
 
+def current_namespace() -> ResolvedId:
+    return _current_namespace.get()
+
+
 def resolve_id(id: Id) -> ResolvedId:
+    """
+    Resolve an ID, possibly with a module namespace.
+
+    Parameters
+    ----------
+    Args
+        id: An ID.
+
+    Returns
+        An ID (if in a module, this will contain a namespace prefix).
+    """
     curr_ns = _current_namespace.get()
     return curr_ns(id)
 
@@ -47,7 +66,7 @@ _current_namespace: ContextVar[ResolvedId] = ContextVar(
 
 
 @contextmanager
-def namespace_context(id: Union[Id, None]):
+def namespace_context(id: Id | None):
     namespace = resolve_id(id) if id else Root
     token: Token[ResolvedId] = _current_namespace.set(namespace)
     try:
