@@ -18,7 +18,14 @@ from ._utils import shiny_input_label
 _Choices = Mapping[str, TagChild]
 
 # Formats available to the user
-ChoicesArg = Union["list[str]", _Choices]
+ChoicesArg = Union[
+    # ["a", "b", "c"]
+    "list[str]",
+    # ("a", "b", "c")
+    "tuple[str, ...]",
+    # {"a": "Choice A", "b": tags.i("Choice B")}
+    _Choices,
+]
 
 
 @add_example()
@@ -65,6 +72,7 @@ def input_checkbox(
                     type="checkbox",
                     checked="checked" if value else None,
                 ),
+                " ",
                 span(label),
             ),
             class_="checkbox",
@@ -131,6 +139,7 @@ def _input_checkbox(
                 type="checkbox",
                 checked="checked" if value else None,
             ),
+            " ",
             tags.label(label, class_="form-check-label", for_=resolve_id(id)),
             class_=class_,
         ),
@@ -279,7 +288,7 @@ def _generate_options(
     id: str,
     type: str,
     choices: ChoicesArg,
-    selected: Optional[str | list[str]],
+    selected: Optional[str | list[str] | tuple[str, ...]],
     inline: bool,
 ) -> Tag:
     choicez = _normalize_choices(choices)
@@ -290,7 +299,9 @@ def _generate_options(
         else:
             selected = []
 
-    if not isinstance(selected, list):
+    if isinstance(selected, tuple):
+        selected = list(selected)
+    elif not isinstance(selected, list):
         selected = [selected]
 
     return div(
@@ -324,13 +335,13 @@ def _generate_option(
         checked="checked" if checked else None,
     )
     if inline:
-        return tags.label(input, span(label), class_=type + "-inline")
+        return tags.label(input, " ", span(label), class_=type + "-inline")
     else:
-        return div(tags.label(input, span(label)), class_=type)
+        return div(tags.label(input, " ", span(label)), class_=type)
 
 
 def _normalize_choices(x: ChoicesArg) -> _Choices:
-    if isinstance(x, list):
+    if isinstance(x, (list, tuple)):
         return {k: k for k in x}
     else:
         return x
