@@ -2,18 +2,13 @@ from __future__ import annotations
 
 __all__ = ("input_file",)
 
-import sys
 from typing import Optional
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 from htmltools import Tag, TagChild, css, div, span, tags
 
 from .._docstring import add_example
 from .._namespaces import resolve_id
+from .._typing_extensions import Literal
 from ._utils import shiny_input_label
 
 
