@@ -7,20 +7,14 @@ __all__ = (
     "modal_remove",
 )
 
-import sys
 from typing import Optional
 
-from shiny.types import MISSING, MISSING_TYPE
-
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 from htmltools import HTML, Tag, TagAttrs, TagAttrValue, TagChild, div, tags
 
 from .._docstring import add_example
+from .._typing_extensions import Literal
 from ..session import Session, require_active_session
+from ..types import MISSING, MISSING_TYPE
 
 
 def modal_button(label: TagChild, icon: TagChild = None, **kwargs: TagAttrValue) -> Tag:
